# Top 15 busiest Facebook Chats

## intro

I was interested in finding out what are those top X facebook chat(s), which are having highest number of messages transacted, I participated in. It doesn't anyhow try to analyse whether I played one important part in that chat or not, rather considers overall chat.

I parsed all facebook messages & found top X _( = 15 )_ high traffic chats. _It includes both private & group chats_.

## example

![top15FacebookChatsWithMostMessagesAnjan_Roy](../plots/top15FacebookChatsWithMostMessagesAnjan_Roy.svg)
